From c0258a6323e477be0ea142b538fee29bd3f5e562 Mon Sep 17 00:00:00 2001
From: Sergey Radionov <RSATom@gmail.com>
Date: Sun, 13 Nov 2011 12:42:52 +0700
Subject: [PATCH 1/1] messages.c: added logging via OutputDebugString under
 windows.

---
 src/misc/messages.c |   25 +++++++++++++++++++++++++
 1 files changed, 25 insertions(+), 0 deletions(-)

diff --git a/src/misc/messages.c b/src/misc/messages.c
index 8bc8b16..007b9cb 100644
--- a/src/misc/messages.c
+++ b/src/misc/messages.c
@@ -132,6 +132,10 @@ void vlc_Log (vlc_object_t *obj, int type, const char *module,
 static void PrintColorMsg (void *, int, const msg_item_t *,
                            const char *, va_list);
 static void PrintMsg (void *, int, const msg_item_t *, const char *, va_list);
+#ifdef WIN32
+static void Win32DebugOutputMsg (void *, int , const msg_item_t *,
+                                 const char *, va_list);
+#endif
 
 /**
  * Emit a log message. This function is the variable argument list equivalent
@@ -230,6 +234,13 @@ void vlc_vaLog (vlc_object_t *obj, int type, const char *module,
         PrintMsg (&priv->i_verbose, type, &msg, format, ap);
     va_end (ap);
 
+#ifdef WIN32
+    va_list dol;
+    va_copy (dol, args);
+    Win32DebugOutputMsg (0, type, &msg, format, dol);
+    va_end (dol);
+#endif
+
     vlc_rwlock_rdlock (&msg_lock);
     for (msg_subscription_t *sub = msg_head; sub != NULL; sub = sub->next)
     {
@@ -303,3 +314,17 @@ static void PrintMsg (void *d, int type, const msg_item_t *p_item,
     funlockfile (stream);
     vlc_restorecancel (canc);
 }
+
+#ifdef WIN32
+static void Win32DebugOutputMsg (void* d, int type, const msg_item_t *p_item,
+                                 const char *format, va_list dol)
+{
+    char od_buf[512];
+    int odml = vsnprintf(od_buf, sizeof(od_buf)-1, format, dol);
+    if(odml>0 && od_buf[odml-1]!='\n'){
+        od_buf[odml]='\n';
+        od_buf[odml+1]='\0';
+    }
+    OutputDebugString(od_buf);
+}
+#endif
-- 
1.7.7.1.msysgit.0

